@@ -90,7 +90,22 @@ flames_add_extra_des(const cpl_frame *ref_frm,
   check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, UVES_RA));
   check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, UVES_DEC));
   check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, "EQUINOX"));//O_POS
-  check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, "RADECSYS"));
+
+  //check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, "RADECSYS"));
+  if (!uves_propertylist_has(out_frm_header, "RADECSYS") && !uves_propertylist_has(out_frm_header, "RADESYS")) {
+    for (char *l[] = {"RADESYS", "RADECSYS", 0}, **i = l; *i; ++i) {
+      if (uves_propertylist_has(ref_frm_header, *i)) {
+        char * radeval = cpl_strdup(uves_propertylist_get_string(ref_frm_header, *i));
+        char * radecmt = cpl_strdup(uves_propertylist_get_comment(ref_frm_header, *i));
+        uves_propertylist_update_string(out_frm_header, "RADESYS", radeval);
+        uves_propertylist_set_comment(out_frm_header, "RADESYS", radecmt);
+        cpl_free(radeval);
+        cpl_free(radecmt);
+        break;
+      }
+    }
+  }
+
   check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, UVES_EXPTIME));
   check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, "DATE-OBS"));//O_TIME
   check_nomsg( uves_copy_if_possible(out_frm_header, ref_frm_header, UVES_AIRMASS));//O_AIRM
