@@ -1552,19 +1552,16 @@ flames_frameset_insert(cpl_frameset *frames,
         }
 
 
-        {
-            int i;
-            for (i = 0; i < uves_propertylist_get_size(primary_header); i++) {
-                cpl_property *p = uves_propertylist_get(primary_header, i);
+        for (int i = 0; i < uves_propertylist_get_size(primary_header); i++) {
+            cpl_property *p = uves_propertylist_get(primary_header, i);
 
-                if (strcmp(cpl_property_get_name(p), "HISTORY") == 0) {
-                    const char *value = cpl_property_get_string(p);
+            if (strcmp(cpl_property_get_name(p), "HISTORY") == 0) {
+                const char *value = cpl_property_get_string(p);
 
-                    if (strstr(value, "ESO-DESCRIPTORS START")) {
-                        cpl_property_set_string(p, "EDS");
-                        /* This is to avoid that MIDAS' INTAPE/FITS command
-                           warns about the header not being in MIDAS format */
-                    }
+                if (strstr(value, "ESO-DESCRIPTORS START")) {
+                    cpl_property_set_string(p, "EDS");
+                    /* This is to avoid that MIDAS' INTAPE/FITS command
+                       warns about the header not being in MIDAS format */
                 }
             }
         }
