@@ -329,11 +329,17 @@ fillholes(
             /* bail out if the function call return an error status */
             if ((status = get_ordpos(ordpos, order, x, &ordercentre))!=NOERR) {
                 free(shiftdata);
+                free(fitdata.offset);
+                free(fitdata.sigma);
+                free(fitdata.value);
                 return(status);
             }
             shiftbufferix->ordercentre = ordercentre;
             if ((status = get_ordslope(ordpos, order, x, &orderslope))!=NOERR) {
                 free(shiftdata);
+                free(fitdata.offset);
+                free(fitdata.sigma);
+                free(fitdata.value);
                 return(status);
             }
             shiftbufferix->orderslope = orderslope;
@@ -346,6 +352,9 @@ fillholes(
             if ((status=calcfillshifts(allflatsin, shiftbuffer, ix))
                             != NOERR) {
                 free(shiftdata);
+                free(fitdata.offset);
+                free(fitdata.sigma);
+                free(fitdata.value);
                 return(status);
             }
         }
@@ -368,6 +377,9 @@ fillholes(
                     if ((status=locatefillfibre(allflatsin, ordpos, shiftbuffer,
                                     iorder, ifibre, ix)) != NOERR) {
                     	free(shiftdata);
+                    	free(fitdata.offset);
+                        free(fitdata.sigma);
+                    	free(fitdata.value);
                         return(status);
                     }
                 }
@@ -413,6 +425,9 @@ fillholes(
                         != NOERR) {
             /* something went wrong while reading the background table */
             SCTPUT("Error while reading the background table");
+            free(fitdata.offset);
+            free(fitdata.sigma);
+            free(fitdata.value);
             return flames_midas_fail();
         }
         if (framebuffer->back.Window_Number > 0) {
@@ -420,15 +435,24 @@ fillholes(
                             badwinysize, badfracthres, badtotthres, kappa2,
                             maxbackiters, maxdiscardfract, OUTPUTI)) {
                 SCTPUT("Error executing the scatter function");
+                free(fitdata.offset);
+                free(fitdata.sigma);
+                free(fitdata.value);
                 return flames_midas_fail();
             }
             /* compute the estimated background */
             if (computeback(framebuffer, backframe) != NOERR) {
                 SCTPUT("Error computing fitted background");
+                free(fitdata.offset);
+                free(fitdata.sigma);
+                free(fitdata.value);
                 return flames_midas_fail();
             }
             if (freeback(&(framebuffer->back)) != NOERR) {
                 SCTPUT("Error freeing framebuffer->back");
+                free(fitdata.offset);
+                free(fitdata.sigma);
+                free(fitdata.value);
                 return flames_midas_fail();
             }
             /* subtract the estimated background from the data frame */
@@ -478,6 +502,9 @@ fillholes(
         }
         else {
             SCTPUT("Error: no regions available for background estimation");
+            free(fitdata.offset);
+            free(fitdata.sigma);
+            free(fitdata.value);
             return flames_midas_fail();
         }
     }
@@ -508,6 +535,9 @@ fillholes(
     if ((status = readslitflats(slitsname, slitflats)) != NOERR) {
         /* problems reading slitflats members from disk */
         SCTPUT("Error while reading the slit Flat Field frames");
+        free(fitdata.offset);
+        free(fitdata.sigma);
+        free(fitdata.value);
         return flames_midas_fail();
     }
     /* uncorrect for the previous ycorrection, if present */
@@ -550,6 +580,9 @@ fillholes(
         if (slitdivide(slitflats, ordpos, framebuffer, framebuffer)!=NOERR) {
             /* something went wrong in slitdivide */
             SCTPUT("Error while dividing the Science Frame by the slit frame(s)");
+            free(fitdata.offset);
+            free(fitdata.sigma);
+            free(fitdata.value);
             return flames_midas_fail();
         }
 
@@ -573,6 +606,9 @@ fillholes(
     /* free the slit flats */
     if (freeslitflats(slitflats)!=NOERR) {
         SCTPUT("Error while freeing the memory for the Slit_FF structure\n");
+        free(fitdata.offset);
+        free(fitdata.sigma);
+        free(fitdata.value);
         return flames_midas_fail();
     }
     free(slitflats);
@@ -604,6 +640,9 @@ fillholes(
     /* allocate and clone from allflatsin the local allflatsout structure */
     allflatsout = (allflats *) calloc(1, sizeof(allflats));
     if ((status = cloneallflats(allflatsin, allflatsout)) != NOERR) {
+    	free(fitdata.offset);
+    	free(fitdata.sigma);
+    	free(fitdata.value);
         return(status);
     }
 
@@ -671,6 +710,9 @@ fillholes(
                     if (fmvecbuf1[ifibreixindex]==GOODSLICE) {
                         if ((status=initfillfibre(allflatsin, iorder, iframe, ifibre, ix,
                                         badifibre, &badtotal)) != NOERR){
+                        	free(fitdata.offset);
+                        	free(fitdata.sigma);
+                        	free(fitdata.value);
                             return(status);
                         }
                     }
@@ -707,6 +749,9 @@ fillholes(
                                                 fillnormfactors(allflatsin, shiftbuffer, badifibre,
                                                                 iorder, iframe, ifibre, ix, ixindex,
                                                                 normdata)) != NOERR) {
+                                	free(fitdata.offset);
+                                	free(fitdata.sigma);
+                                	free(fitdata.value);
                                     return(status);
                                 }
                                 /* now we have normalisation factors and we know which bad
@@ -721,6 +766,9 @@ fillholes(
                                                     selectfillavail(allflatsin, shiftbuffer,
                                                                     normdata, &fitdata, iorder, iframe,
                                                                     ix, iy)) != NOERR) {
+                                    	free(fitdata.offset);
+                                    	free(fitdata.sigma);
+                                    	free(fitdata.value);
                                         return(status);
                                     }
                                     /* Do the interpolation (if possible) and put interpolated
@@ -734,6 +782,9 @@ fillholes(
                                     if ((status =
                                                     dointerpolate(allflatsout, &fitdata, iorder, iframe,
                                                                     ifibre, ix, iy)) !=NOERR) {
+                                    	free(fitdata.offset);
+                                    	free(fitdata.sigma);
+                                    	free(fitdata.value);
                                         return(status);
                                     }
                                     /* was the correction successful? */
