@@ -114,14 +114,12 @@ initemplate(flames_frame *myframe,
     memset(h_gain_l, 0, 18);
     memset(h_gain_u, 0, 18);
     /* try to open the frame */
-    if ((status = SCFOPN(filename, FLAMESDATATYPE, 0, F_IMA_TYPE, &fileid))
-                    != 0) {
+    if (0 != SCFOPN(filename, FLAMESDATATYPE, 0, F_IMA_TYPE, &fileid)) {
         /* I could not open the frame */
         return(MAREMMA);
     }
     /* is it a 2D image? */
-    if ((status = SCDRDI(fileid, "NAXIS", 1, 1, &actvals, &naxis, &unit,
-                    &null)) != 0) {
+    if (0 != SCDRDI(fileid, "NAXIS", 1, 1, &actvals, &naxis, &unit, &null)) {
         /* something went wrong in SCDRDI */
         return(MAREMMA);
     }
@@ -132,26 +130,23 @@ initemplate(flames_frame *myframe,
 
     /* read all relevant scalar descriptors */
     /* read start, step and npix from the frame */
-    if ((status=SCDRDD(fileid, "START", 1, naxis, &actvals, start, &unit,
-                    &null)) != 0) {
+    if (0 != SCDRDD(fileid, "START", 1, naxis, &actvals, start, &unit, &null)) {
         /* something went wrong in SCDRDD */
         return(status);
     }
-    if ((status=SCDRDD(fileid, "STEP", 1, naxis, &actvals, step, &unit,
-                    &null)) != 0) {
+    if (0 != SCDRDD(fileid, "STEP", 1, naxis, &actvals, step, &unit, &null)) {
         /* something went wrong in SCDRDD */
         return(status);
     }
-    if ((status=SCDRDI(fileid, "NPIX", 1, naxis, &actvals, npix, &unit,
-                    &null)) != 0) {
+    if (0 != SCDRDI(fileid, "NPIX", 1, naxis, &actvals, npix, &unit, &null)) {
         /* something went wrong in SCDRDI */
         return(status);
     }
     /* Where should the maxfibres information be stored? The most sensible
      way would perhaps be a frame descriptor in the ESO.* hierarchy.
      Remember to talk to amodigli about this */
-    if ((status = SCDRDC(fileid, "CHIPCHOICE", 1, 1, 1, &actvals,
-                    &chipchoice, &unit, &null)) != 0) {
+    if (0 != SCDRDC(fileid, "CHIPCHOICE", 1, 1, 1, &actvals, &chipchoice, &unit,
+    		&null)) {
         /* something went wrong in SCDRDC */
         return(status);
     }
@@ -159,22 +154,22 @@ initemplate(flames_frame *myframe,
 
 
 
-    if ((status = SCKRDC(H_RON_L,16,1,1,&actvals, h_ron_l, &unit, &null)) != 0) {
+    if (0 != SCKRDC(H_RON_L,16,1,1,&actvals, h_ron_l, &unit, &null)) {
         /* something went wrong in SCDRDC */
         return(status);
     }
-    if ((status = SCKRDC(H_RON_U,16,1,1,&actvals, h_ron_u, &unit, &null)) != 0) {
+    if ( 0 != SCKRDC(H_RON_U,16,1,1,&actvals, h_ron_u, &unit, &null)) {
         /* something went wrong in SCDRDC */
         return(status);
     }
 
 
-    if ((status = SCKRDC(H_GAIN_L,17,1,1,&actvals, h_gain_l, &unit, &null)) != 0) {
+    if (0 != SCKRDC(H_GAIN_L,17,1,1,&actvals, h_gain_l, &unit, &null)) {
         /* something went wrong in SCDRDC */
         return(status);
     }
 
-    if ((status = SCKRDC(H_GAIN_U,17,1,1,&actvals, h_gain_u, &unit, &null)) != 0) {
+    if (0 != SCKRDC(H_GAIN_U,17,1,1,&actvals, h_gain_u, &unit, &null)) {
         /* something went wrong in SCDRDC */
         return(status);
     }
@@ -182,13 +177,11 @@ initemplate(flames_frame *myframe,
     switch(chipchoice) {
     case 'u':
         /* upper chip, read the corresponding data */
-        if ((status=SCDRDD(fileid, h_ron_l, 1, 1, &actvals, &ron,
-                        &unit, &null)) != 0) {
+        if (0 !=SCDRDD(fileid, h_ron_l, 1, 1, &actvals, &ron, &unit, &null)) {
             /* something went wrong in SCDRDD */
             return(status);
         }
-        if ((status=SCDRDD(fileid, h_gain_l, 1, 1, &actvals, &gain,
-                        &unit, &null)) != 0) {
+        if (0 !=SCDRDD(fileid, h_gain_l, 1, 1, &actvals, &gain, &unit, &null)) {
             /* something went wrong in SCDRDD */
             return(status);
         }
@@ -197,14 +190,12 @@ initemplate(flames_frame *myframe,
     case 'l':
         /* lower chip, read the corresponding data */
         /* why h_ron_u=OUT4 is used in lower chip case */
-        if ((status=SCDRDD(fileid, h_ron_u, 1, 1, &actvals, &ron,
-                        &unit, &null)) != 0) {
+        if (0 !=SCDRDD(fileid, h_ron_u, 1, 1, &actvals, &ron, &unit, &null)) {
             /* something went wrong in SCDRDD */
             return(status);
         }
         /* why h_gain_u=OUT4 is used in lower chip case */
-        if ((status=SCDRDD(fileid, h_gain_u, 1, 1, &actvals, &gain,
-                        &unit, &null)) != 0) {
+        if (0 !=SCDRDD(fileid, h_gain_u, 1, 1, &actvals, &gain, &unit, &null)) {
             /* something went wrong in SCDRDD */
             return(status);
         }
@@ -215,8 +206,8 @@ initemplate(flames_frame *myframe,
         return(MAREMMA);
         break;
     }
-    if ((status=SCDRDI(fileid, "MAXFIBRES", 1, 1, &actvals, &maxfibres, &unit,
-                    &null)) != 0) {
+    if (0 !=SCDRDI(fileid, "MAXFIBRES", 1, 1, &actvals, &maxfibres, &unit,
+                    &null)) {
         /* something went wrong in SCDRDI */
         return(status);
     }
@@ -252,7 +243,7 @@ initemplate(flames_frame *myframe,
     myframe->back.Window_Number = 0;
 
     /* allocate dynamic submembers here */
-    if ((status = alloctemplate(myframe)) != NOERR) {
+    if (NOERR != alloctemplate(myframe)) {
         /* alloctemplate returned an error */
         return(MAREMMA);
     }
@@ -265,7 +256,7 @@ initemplate(flames_frame *myframe,
     }
 
     /* close image frame */
-    if ((status = SCFCLO(fileid)) != 0) {
+    if (0 != SCFCLO(fileid)) {
         /* error closing image file */
         return(MAREMMA);
     }
