@@ -91,7 +91,7 @@ initshiftedff(
     int32_t iframe=0;
     int32_t ifibre=0;
     int32_t iorderifibreixtotal=0;
-    int status=0;
+    //int status=0;
 
     iorderifibreixtotal = ((1+allflatsin->lastorder-allflatsin->firstorder)*
                     allflatsin->maxfibres*allflatsin->subcols);
@@ -131,7 +131,7 @@ initshiftedff(
     allflatsout->normalised = allflatsin->normalised;
 
     /* allocate array members of allflatsout */
-    if ((status = alloconeflats(allflatsout)) != NOERR) {
+    if (NOERR != alloconeflats(allflatsout)) {
         /* error allocating allflatsout */
         return flames_midas_fail();
     }
