@@ -825,8 +825,8 @@ exit ***\n");
         frame_data* fdvecbuf4 = ScienceFrame->normsigma[0][0];
         frame_data* fdvecbuf5 = ScienceFrame->specsigma[0][0];
         frame_data* fdvecbuf6 = ScienceFrame->normspec[0][0];
-        frame_data* fmvecbuf2 = ScienceFrame->specmask[0][0];
-        frame_data* fmvecbuf3 = ScienceFrame->normmask[0][0];
+        frame_mask* fmvecbuf2 = ScienceFrame->specmask[0][0];
+        frame_mask* fmvecbuf3 = ScienceFrame->normmask[0][0];
         for (ifibre=0; ifibre<=(ScienceFrame->maxfibres-1); ifibre++) {
             /* is this fibre lit? */
             if ((ScienceFrame->fibremask[ifibre] == TRUE) &&
