@@ -964,14 +964,14 @@ test_flames_reset_desc3(void)
   char iname[MED_NAME_SIZE];
   int cub_id;
   int ima_id;
-  int status;
+
 
   SCSPRO("test");
   sprintf(cname,"%s","slitff_l_dtc.fits");
   sprintf(iname,"%s","slitff_l_data01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
   uves_msg_warning("This is supposed to work");
   check_nomsg(flames_reset_desc_set2(ima_id,cub_id,1));
   uves_msg_warning("The following should crash");
@@ -994,8 +994,8 @@ test_flames_reset_desc3(void)
   sprintf(cname,"%s","slitff_l_bpc.fits");
   sprintf(iname,"%s","slitff_l_badpixel01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
 
   check_nomsg(flames_reset_desc_set3(ima_id,cub_id,2,1));
   uves_msg_warning("now fibff");
@@ -1012,8 +1012,8 @@ test_flames_reset_desc3(void)
   sprintf(cname,"%s","slitff_l_sgc.fits");
   sprintf(iname,"%s","slitff_l_sigma01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
   check_nomsg(flames_reset_desc_set3(ima_id,cub_id,2,1));
   uves_msg_warning("now fibff");
   /* Set FIBFF */
@@ -1029,8 +1029,8 @@ test_flames_reset_desc3(void)
   sprintf(cname,"%s","slitff_l_bnc.fits");
   sprintf(iname,"%s","slitff_l_bound01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
   uves_msg_warning("This is supposed to work");
   check_nomsg(flames_reset_desc_set2(ima_id,cub_id,1));
   uves_msg_warning("The following should crash");
@@ -1056,8 +1056,8 @@ test_flames_reset_desc3(void)
   sprintf(cname,"%s","fibreff_l_dtc.fits");
   sprintf(iname,"%s","fibreff_l_data01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
 
   uves_msg_warning("This is supposed to work");
   check_nomsg(flames_reset_desc_set2(ima_id,cub_id,1));
@@ -1074,8 +1074,8 @@ test_flames_reset_desc3(void)
   sprintf(cname,"%s","fibreff_l_sgc.fits");
   sprintf(iname,"%s","fibreff_l_sigma01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
 
   uves_msg_warning("This is supposed to work");
   check_nomsg(flames_reset_desc_set3(ima_id,cub_id,2,2));
@@ -1090,8 +1090,8 @@ test_flames_reset_desc3(void)
   sprintf(cname,"%s","fibreff_l_bpc.fits");
   sprintf(iname,"%s","fibreff_l_badpixel01.fits");
 
-  status = SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
-  status = SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
+  SCFOPN(cname, FLAMESDATATYPE, 0, F_IMA_TYPE, &cub_id);
+  SCFOPN(iname, FLAMESDATATYPE, 0, F_IMA_TYPE, &ima_id);
 
   uves_msg_warning("This is supposed to work");
   check_nomsg(flames_reset_desc_set3(ima_id,cub_id,2,2));
