@@ -172,7 +172,7 @@ irplib_stdstar_write_catalogs(cpl_frameset        *   set_in,
   @brief    Load the FITS catalog in a table
   @param    filename    Name of the FITS catalog
   @param    ext_name    Name of the catalog or "all"
-  @return   The newly allocated table orNULL in error case.
+  @return   The newly allocated table on NULL in error case.
 
   The table is loaded from the specified extension.
   If "all" is specified, all extension with the same columns as the
