@@ -402,6 +402,7 @@ uves_utl_remove_crh_single( cpl_parameterlist   *   parlist,
 	}
 	name2=cpl_frame_get_filename(frame_off);
         uves_msg("Bias file name =%s",name2);
+	check_nomsg(uves_sanitise_propertylist(plist1));
 	check_nomsg(cpl_image_save(NULL, name_r,CPL_BPP_IEEE_FLOAT,
 				   plist1,CPL_IO_DEFAULT));
 
@@ -429,6 +430,7 @@ uves_utl_remove_crh_single( cpl_parameterlist   *   parlist,
 
 	  check_nomsg(cpl_image_add(ima_res,ima_off));
       
+	  check_nomsg(uves_sanitise_propertylist(plist1));
 	  check_nomsg(cpl_image_save(ima_res, name_r,CPL_BPP_IEEE_FLOAT,
 				     plist1,CPL_IO_DEFAULT));
 	} else {
@@ -470,10 +472,9 @@ uves_utl_remove_crh_single( cpl_parameterlist   *   parlist,
 	    check_nomsg(cpl_image_add(ima_res,ima_off));
 
  
-	    if(i>0) {
-	      check_nomsg(cpl_image_save(ima_res, name_r,CPL_BPP_IEEE_FLOAT,
+	    check_nomsg(uves_sanitise_propertylist(pliste));
+	    check_nomsg(cpl_image_save(ima_res, name_r,CPL_BPP_IEEE_FLOAT,
 					 pliste,CPL_IO_EXTEND));
-	    }
 	    uves_free_image(&ima_on);
 	    uves_free_image(&ima_off);
 	    uves_free_image(&ima_res);
