@@ -358,11 +358,8 @@ For Red data:  PRO.CATG=MWXB_SCI_REDL, MWXB_SCI_REDU"""
       paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='ext_method',group='extract',description="""Extraction method. <std | opt | fst | fop> [opt]"""))
 
 #      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='cor_max_fnd',group='extract',description="""Find correlation maximum?. <N | Y> [Y]"""))
-
-      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='cor_max_ rng',group='extract',description="""Correlation range size?. [6.0]"""))
-
-      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='cor_max_ pnt',group='extract',description="""Correlation sampling points?. [25]"""))
-
+#      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='cor_def_rng',group='extract',description="""Correlation range size?. [6.0]"""))
+#      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='cor_def_pnt',group='extract',description="""Correlation sampling points?. [25]"""))
       paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='cor_def_off',group='extract',description="""Correlation center offset?. [0.0]"""))
 
       paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='corvel_iter',group='extract',description="""Velocity correlation iteration number (SimCal). [1]"""))
