@@ -3,6 +3,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 try:
   import reflex
+  import pipeline_product
   import_sucess = True
 
 #NOTE for developers: 
@@ -42,7 +43,16 @@ try:
       #Read all the products
       frames = dict()
       for frame in fitsFiles:
-        if frame == '' :
+        if frame == '': continue
+        try:
+          pp = pipeline_product.PipelineProduct(frame)
+          pro_rec1_id = pp.readKeyword('ESO PRO REC1 ID')
+        except KeyError:
+          pro_rec1_id = '<missing>'
+        if pro_rec1_id == 'uves_cal_predict':
+          print('Keeping {} with PRO.REC1.ID={}'.format(frame.category, pro_rec1_id))
+        else:
+          print('Tossing {} with PRO.REC1.ID={}'.format(frame.category, pro_rec1_id))
           continue
         category = frame.category
         frames[category] = frame
