@@ -626,8 +626,8 @@ class PlotableLineTable(ScatterPlot):
     self.loadFromFits(self.table)
   
   def loadFromFits(self, table) :
-    n_win                = (table.all_hdu.__len__() - 1 )/3
-    id_win               = (n_win+1)/2
+    n_win                = (table.all_hdu.__len__() - 1 )//3
+    id_win               = (n_win+1)//2
     ext_id               = 3 * (id_win -1 ) + 1
     self.x_raw           = table.all_hdu[ext_id].data.field('X')
     self.ynew_raw        = table.all_hdu[ext_id].data.field('Ynew')
