@@ -99,8 +99,13 @@ float *vector(int32_t nl, int32_t nh)
   float *v;
 
   v=(float *) calloc((size_t) (nh-nl+1+NR_END), sizeof(float));
-  if (!v) nrerror("allocation failure in vector()");
-  return v-nl+NR_END;
+  if (!v) {
+     nrerror("allocation failure in vector()");
+     free(v);
+     return NULL;
+  } else {
+     return v-nl+NR_END;
+  }
 }
 
 int *ivector(int32_t nl, int32_t nh)
@@ -109,8 +114,13 @@ int *ivector(int32_t nl, int32_t nh)
   int *v;
 
   v=(int *) calloc((size_t) (nh-nl+1+NR_END), sizeof(int));
-  if (!v) nrerror("allocation failure in ivector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in ivector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 unsigned int *uivector(int32_t nl, int32_t nh)
@@ -120,8 +130,13 @@ unsigned int *uivector(int32_t nl, int32_t nh)
 
   v=(unsigned int *) calloc((size_t) (nh-nl+1+NR_END), 
 			    sizeof(unsigned int));
-  if (!v) nrerror("allocation failure in uivector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in uivector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 char *cvector(int32_t nl, int32_t nh)
@@ -130,8 +145,13 @@ char *cvector(int32_t nl, int32_t nh)
   char *v;
 
   v=(char *) calloc((size_t) (nh-nl+1+NR_END), sizeof(char));
-  if (!v) nrerror("allocation failure in cvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in cvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 unsigned char *ucvector(int32_t nl, int32_t nh)
@@ -141,8 +161,13 @@ unsigned char *ucvector(int32_t nl, int32_t nh)
 
   v=(unsigned char *) calloc((size_t) (nh-nl+1+NR_END), 
 			     sizeof(unsigned char));
-  if (!v) nrerror("allocation failure in ucvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in ucvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 int32_t *lvector(int32_t nl, int32_t nh)
@@ -151,8 +176,13 @@ int32_t *lvector(int32_t nl, int32_t nh)
   int32_t *v;
 
   v=(int32_t *) calloc((size_t) (nh-nl+1+NR_END), sizeof(int32_t));
-  if (!v) nrerror("allocation failure in lvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in lvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 uint32_t *ulvector(int32_t nl, int32_t nh)
@@ -162,8 +192,13 @@ uint32_t *ulvector(int32_t nl, int32_t nh)
 
   v=(uint32_t *) calloc((size_t) (nh-nl+1+NR_END), 
 			     sizeof(uint32_t));
-  if (!v) nrerror("allocation failure in ulvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in ulvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 double *dvector(int32_t nl, int32_t nh)
@@ -172,8 +207,13 @@ double *dvector(int32_t nl, int32_t nh)
   double *v;
 
   v=(double *) calloc((size_t) (nh-nl+1+NR_END), sizeof(double));
-  if (!v) nrerror("allocation failure in dvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in dvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 frame_data *fdvector(int32_t nl, int32_t nh)
@@ -182,8 +222,13 @@ frame_data *fdvector(int32_t nl, int32_t nh)
   frame_data *v;
 
   v=(frame_data *) calloc((size_t) (nh-nl+1+NR_END), sizeof(frame_data));
-  if (!v) nrerror("allocation failure in fdvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in fdvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 frame_mask *fmvector(int32_t nl, int32_t nh)
@@ -192,8 +237,13 @@ frame_mask *fmvector(int32_t nl, int32_t nh)
   frame_mask *v;
 
   v=(frame_mask *) calloc((size_t) (nh-nl+1+NR_END), sizeof(frame_mask));
-  if (!v) nrerror("allocation failure in fdvector()");
-  return v-nl+NR_END;
+  if (!v) {
+	  nrerror("allocation failure in fdvector()");
+	  free(v);
+	  return NULL;
+  } else {
+      return v-nl+NR_END;
+  }
 }
 
 char **cmatrix(int32_t nrl, int32_t nrh, int32_t ncl, int32_t nch)
@@ -728,7 +778,7 @@ void free_vector(float *v, int32_t nl, int32_t nh)
 /* free a float vector allocated with vector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -736,7 +786,7 @@ void free_ivector(int *v, int32_t nl, int32_t nh)
 /* free an int vector allocated with ivector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -744,7 +794,7 @@ void free_uivector(unsigned int *v, int32_t nl, int32_t nh)
 /* free an unsigned int vector allocated with uivector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -752,7 +802,7 @@ void free_cvector(char *v, int32_t nl, int32_t nh)
 /* free a char vector allocated with cvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -760,7 +810,7 @@ void free_ucvector(unsigned char *v, int32_t nl, int32_t nh)
 /* free an unsigned char vector allocated with ucvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -768,7 +818,7 @@ void free_lvector(int32_t *v, int32_t nl, int32_t nh)
 /* free an uint32_t vector allocated with lvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -776,7 +826,7 @@ void free_ulvector(uint32_t *v, int32_t nl, int32_t nh)
 /* free an uint32_t vector allocated with ulvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -784,7 +834,7 @@ void free_dvector(double *v, int32_t nl, int32_t nh)
 /* free a double vector allocated with dvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -792,7 +842,7 @@ void free_fdvector(frame_data *v, int32_t nl, int32_t nh)
 /* free a double vector allocated with dvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -800,7 +850,7 @@ void free_fmvector(frame_mask *v, int32_t nl, int32_t nh)
 /* free a double vector allocated with dvector() */
 {
   //to remove comp warning: not used
-  nh=nh;
+  //nh=nh;
   free((FREE_ARG) (v+nl-NR_END));
 }
 
@@ -808,9 +858,9 @@ void free_matrix(float **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nch)
 /* free a float matrix allocated by matrix() */
 { 
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -819,9 +869,9 @@ void free_cmatrix(char **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nch)
 /* free a float matrix allocated by cmatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -830,9 +880,9 @@ void free_dmatrix(double **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nch
 /* free a double matrix allocated by dmatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -841,9 +891,9 @@ void free_imatrix(int **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nch)
 /* free an int matrix allocated by imatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -852,9 +902,9 @@ void free_ulmatrix(uint32_t **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_t
 /* free an int matrix allocated by imatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -863,9 +913,9 @@ void free_lmatrix(int32_t **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nc
 /* free an int matrix allocated by imatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -874,9 +924,9 @@ void free_fdmatrix(frame_data **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_
 /* free an frame_data matrix allocated by imatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -885,9 +935,9 @@ void free_fmmatrix(frame_mask **m, int32_t nrl, int32_t nrh, int32_t ncl, int32_
 /* free an int matrix allocated by imatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   free((FREE_ARG) (m[nrl]+ncl-NR_END));
   free((FREE_ARG) (m+nrl-NR_END));
 }
@@ -896,11 +946,11 @@ void free_submatrix(float **b, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nc
 /* free a submatrix allocated by submatrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  ncl=ncl;
+  //ncl=ncl;
 
   free((FREE_ARG) (b+nrl-NR_END));
 }
@@ -909,11 +959,11 @@ void free_convert_matrix(float **b, int32_t nrl, int32_t nrh, int32_t ncl, int32
 /* free a matrix allocated by convert_matrix() */
 {
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  ncl=ncl;
+  //ncl=ncl;
   free((FREE_ARG) (b+nrl-NR_END));
 }
 
@@ -922,11 +972,11 @@ void free_f3tensor(float ***t, int32_t nrl, int32_t nrh, int32_t ncl, int32_t nc
 /* free a float f3tensor allocated by f3tensor() */
 {
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
 
   free((FREE_ARG) (t[nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nrl]+ncl-NR_END));
@@ -938,11 +988,11 @@ void free_d3tensor(double ***t, int32_t nrl, int32_t nrh, int32_t ncl, int32_t n
 /* free a double 3tensor allocated by d3tensor() */
 {
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
 
   free((FREE_ARG) (t[nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nrl]+ncl-NR_END));
@@ -954,11 +1004,11 @@ void free_fd3tensor(frame_data ***t, int32_t nrl, int32_t nrh, int32_t ncl, int3
 /* free a frame_data f3tensor allocated by f3tensor() */
 {
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
   free((FREE_ARG) (t[nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nrl]+ncl-NR_END));
   free((FREE_ARG) (t+nrl-NR_END));
@@ -969,11 +1019,11 @@ void free_fm3tensor(frame_mask ***t, int32_t nrl, int32_t nrh, int32_t ncl, int3
 /* free a float f3tensor allocated by f3tensor() */
 {
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
   free((FREE_ARG) (t[nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nrl]+ncl-NR_END));
   free((FREE_ARG) (t+nrl-NR_END));
@@ -984,11 +1034,11 @@ void free_ul3tensor(uint32_t ***t, int32_t nrl, int32_t nrh, int32_t ncl, int32_
 /* free a float f3tensor allocated by f3tensor() */
 {
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
 
   free((FREE_ARG) (t[nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nrl]+ncl-NR_END));
@@ -1000,11 +1050,11 @@ void free_l3tensor(int32_t ***t, int32_t nrl, int32_t nrh, int32_t ncl, int32_t
 /* free a float f3tensor allocated by f3tensor() */
 {
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
   free((FREE_ARG) (t[nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nrl]+ncl-NR_END));
   free((FREE_ARG) (t+nrl-NR_END));
@@ -1015,13 +1065,13 @@ void free_l4tensor(int32_t ****t, int32_t nal, int32_t nah, int32_t nrl, int32_t
 /* free an integer l4tensor allocated by f3tensor() */
 {
   //to remove comp warning: not used
-  nah=nah;
+  //nah=nah;
   //to remove comp warning: not used
-  nrh=nrh;
+  //nrh=nrh;
   //to remove comp warning: not used
-  nch=nch;  
+  //nch=nch;
   //to remove comp warning: not used
-  ndh=ndh;
+  //ndh=ndh;
 
   free((FREE_ARG) (t[nal][nrl][ncl]+ndl-NR_END));
   free((FREE_ARG) (t[nal][nrl]+ncl-NR_END));
