@@ -404,11 +404,13 @@ flames_reduce_vcorrel(const char* sci_pfx,
    } //end loop over orders
 
 
+   check_nomsg(uves_sanitise_propertylist(plist_ima_new));
    check_nomsg(cpl_image_save(tim_ccf_ima, "tot_ima.fits",CPL_BPP_IEEE_FLOAT,
 			      plist_ima_new,CPL_IO_DEFAULT));
    check_nomsg(cpl_image_save(nim_ccf_ima, "nrm_ima.fits",CPL_BPP_IEEE_FLOAT,
 			      plist_ima_new,CPL_IO_DEFAULT));
  
+   check_nomsg(uves_sanitise_propertylist(plist_tbl_new));
    check_nomsg(cpl_table_save(cvel_tbl, plist_tbl_new, NULL, otab, 
 			      CPL_IO_DEFAULT));
  
