@@ -301,6 +301,8 @@
                        ((chip) == UVES_CHIP_REDU) ? "DRS_SETUP_REDU" :      \
                        ((chip) == UVES_CHIP_REDL) ? "DRS_SETUP_REDL" : "???"))
     
+
+
 #define UVES_DRS_SETUP_EXTENSION(chip)  1
 
 /* Order table (written by physmod + flames_cal_orderpos) */
@@ -341,6 +343,9 @@
 #define UVES_ORDER_TABLE_EXTENSION_POLY  2
 #define UVES_ORDER_TABLE_EXTENSION_FIBRE 3
 
+#define RESPONSE_WINDOWS		           "RESPONSE_WINDOWS"
+#define QUALITY_AREAS		               "QUALITY_AREAS"
+#define FIT_AREAS		                   "FIT_AREAS"
 
 /* Flame science products
 FIB_SCI_INFO_TAB
@@ -439,6 +444,16 @@ XB_SCI_RAW_REDU
                       ((chip) == UVES_CHIP_REDL) ? "MASTER_BIAS_REDL" : "???")
 #define UVES_MASTER_BIAS_EXTENSION(chip) 0
 
+#define UVES_BIAS_PD(chip)           (((chip) == UVES_CHIP_BLUE) ? "BIAS_PD_BLUE" :  \
+                      ((chip) == UVES_CHIP_REDU) ? "BIAS_PD_REDU" :  \
+                      ((chip) == UVES_CHIP_REDL) ? "BIAS_PD_REDL" : "???")
+
+#define UVES_BIAS_PD_MASK(chip)           (((chip) == UVES_CHIP_BLUE) ? "BIAS_PD_MASK_BLUE" :  \
+                      ((chip) == UVES_CHIP_REDU) ? "BIAS_PD_MASK_REDU" :  \
+                      ((chip) == UVES_CHIP_REDL) ? "BIAS_PD_MASK_REDL" : "???")
+
+
+
 /* Master Formatcheck */
 #define UVES_MASTER_ARC_FORM(chip) (((chip) == UVES_CHIP_BLUE) ? "MASTER_FORM_BLUE" : \
                                     ((chip) == UVES_CHIP_REDU) ? "MASTER_FORM_REDU" : \
@@ -538,6 +553,11 @@ XB_SCI_RAW_REDU
 #define UVES_INSTR_RESPONSE(chip) (((chip) == UVES_CHIP_BLUE) ? "INSTR_RESPONSE_BLUE" : \
                                    ((chip) == UVES_CHIP_REDU) ? "INSTR_RESPONSE_REDU" : \
                                    ((chip) == UVES_CHIP_REDL) ? "INSTR_RESPONSE_REDL" : "???")
+
+
+#define UVES_INSTR_RESPONSE_FINE(chip) (((chip) == UVES_CHIP_BLUE) ? "INSTR_RESPONSE_FINE_BLUE" : \
+                                   ((chip) == UVES_CHIP_REDU) ? "INSTR_RESPONSE_FINE_REDU" : \
+                                   ((chip) == UVES_CHIP_REDL) ? "INSTR_RESPONSE_FINE_REDL" : "???")
 #define UVES_INSTR_RESPONSE_EXTENSION(chip) 0
 
 #define UVES_MASTER_RESPONSE(chip) (((chip) == UVES_CHIP_BLUE) ? "MASTER_RESPONSE_BLUE" : \
@@ -582,6 +602,7 @@ XB_SCI_RAW_REDU
 
 #define UVES_LINE_INTMON_TABLE           "LINE_INTMON_TABLE"
 #define UVES_LINE_INTMON_TABLE_EXTENSION 1
+#define UVES_RESPONSE_TABLE_EXTENSION 1
 
 /* Standard star flux */
 #define UVES_FLUX_STD_TABLE           "FLUX_STD_TABLE"
@@ -591,6 +612,12 @@ XB_SCI_RAW_REDU
 #define UVES_EXTCOEFF_TABLE           "EXTCOEFF_TABLE"
 #define UVES_EXTCOEFF_TABLE_EXTENSION 1
 
+
+#define FLUX_STD_TABLE                     "FLUX_STD_TABLE"
+#define FLUX_STD_CATALOG                   "FLUX_STD_CATALOG"
+#define TELL_MOD_CATALOG                   "TELL_MOD_CATALOG"
+#define RESP_FIT_POINTS_CAT                "RESP_FIT_POINTS_CATALOG"
+
 /*
  *  Image statistics
  */
@@ -626,7 +653,8 @@ cpl_error_code
 uves_sflats_get_encoder_steps(const cpl_frameset * set, cpl_table** encoder_tbl, int* nset);
 
 cpl_error_code uves_dfs_set_groups(cpl_frameset *);
-
+char *
+uves_scired_hdrl_fluxcal_science_filename(enum uves_chip chip);
 cpl_image *
 uves_crop_and_rotate(const cpl_image *image, const uves_propertylist *header,
              enum uves_chip chip,
@@ -858,7 +886,8 @@ cpl_error_code uves_load_atmo_ext(const cpl_frameset *frames,
 
 /* Mbias */
 char *uves_masterbias_filename(enum uves_chip chip);
-
+char *uves_fpn_filename(enum uves_chip chip);
+char *uves_fpn_mask_filename(enum uves_chip chip);
 /* Mdark */
 char *uves_masterdark_filename(enum uves_chip chip);
 
@@ -877,6 +906,7 @@ char *uves_line_table_filename(enum uves_chip chip);
 char *uves_line_table_filename_paf(enum uves_chip chip);
 
 /* Response */
+char *uves_response_hdrl_filename(enum uves_chip chip);
 char *uves_response_curve_filename(enum uves_chip chip);
 char *uves_response_curve_2d_filename(enum uves_chip chip);
 char *uves_response_red_standard_filename(enum uves_chip chip);
