@@ -278,99 +278,99 @@ UVES_CONCAT2X(UVES_MBIAS_ID,exe)(cpl_frameset *frames,
 
 static cpl_error_code
 uves_mbias_fpn(const cpl_imagelist *raw_images,bool blue, enum uves_chip chip,
-		const char* recipe_id, const int binx, const int biny,
-		const int dc_mask_x, const int dc_mask_y,
-		const cpl_parameterlist* parameters, cpl_frameset *frames){
+        const char* recipe_id, const int binx, const int biny,
+        const int dc_mask_x, const int dc_mask_y,
+        const cpl_parameterlist* parameters, cpl_frameset *frames){
 
-	int raw_index = uves_chip_get_index(chip);
+    int raw_index = uves_chip_get_index(chip);
     const char* bias_raw_tag=UVES_BIAS(blue);
     const char* power_spectrum_mask_tag=UVES_BIAS_PD_MASK(chip);
 
-	/* Create the raw and powerspec_mask framesets (only RAW and POWERSPEC_MASK) */
-	cpl_size     nframes  = cpl_frameset_get_size(frames);
-	cpl_frameset *fs_raws = cpl_frameset_new();
-	cpl_frameset *fs_masks = cpl_frameset_new();
+    /* Create the raw and powerspec_mask framesets (only RAW and POWERSPEC_MASK) */
+    cpl_size     nframes  = cpl_frameset_get_size(frames);
+    cpl_frameset *fs_raws = cpl_frameset_new();
+    cpl_frameset *fs_masks = cpl_frameset_new();
 
-	for (cpl_size i = 0; i < nframes; i++) {
+    for (cpl_size i = 0; i < nframes; i++) {
 
-		cpl_frame  *frame    = cpl_frameset_get_position(frames, i);
-		const char *filename = cpl_frame_get_filename(frame);
+        cpl_frame  *frame    = cpl_frameset_get_position(frames, i);
+        const char *filename = cpl_frame_get_filename(frame);
 
-		if (!strcmp(cpl_frame_get_tag(frame), bias_raw_tag)) {
-			cpl_frameset_insert(fs_raws, cpl_frame_duplicate(frame));
+        if (!strcmp(cpl_frame_get_tag(frame), bias_raw_tag)) {
+            cpl_frameset_insert(fs_raws, cpl_frame_duplicate(frame));
 
-		} else if (!strcmp(cpl_frame_get_tag(frame), power_spectrum_mask_tag)) {
-			cpl_frameset_insert(fs_masks, cpl_frame_duplicate(frame));
-		}
-	}
+        } else if (!strcmp(cpl_frame_get_tag(frame), power_spectrum_mask_tag)) {
+            cpl_frameset_insert(fs_masks, cpl_frame_duplicate(frame));
+        }
+    }
 
-	cpl_size n_masks = cpl_frameset_count_tags(frames, power_spectrum_mask_tag);
-	//uves_msg("n_masks=%d",n_masks);
-	int n_ima = cpl_imagelist_get_size(raw_images);
-	cpl_image *img_in=NULL;
-	int ext_mask=0; // TODO: define this
+    cpl_size n_masks = cpl_frameset_count_tags(frames, power_spectrum_mask_tag);
+    //uves_msg("n_masks=%d",n_masks);
+    int n_ima = cpl_imagelist_get_size(raw_images);
+    cpl_image *img_in=NULL;
+    int ext_mask=0; // TODO: define this
 
-	char *out_filename = cpl_sprintf("%s",uves_fpn_filename(chip));
-	char *out_filename_mask = cpl_sprintf("%s",uves_fpn_mask_filename(chip));
-	for (int n_frame = 0; n_frame < n_ima; n_frame++) {
+    char *out_filename = cpl_sprintf("%s",uves_fpn_filename(chip));
+    char *out_filename_mask = cpl_sprintf("%s",uves_fpn_mask_filename(chip));
+    for (int n_frame = 0; n_frame < n_ima; n_frame++) {
 
-		img_in = cpl_imagelist_get_const(raw_images,n_frame);
-		cpl_frame  *frm_raw      = cpl_frameset_get_position(fs_raws, n_frame);
-		const char *filename_raw = cpl_frame_get_filename(frm_raw);
+        img_in = cpl_imagelist_get_const(raw_images,n_frame);
+        cpl_frame  *frm_raw      = cpl_frameset_get_position(fs_raws, n_frame);
+        const char *filename_raw = cpl_frame_get_filename(frm_raw);
 
-		/* Compute Pattern noise */
-		cpl_image *power_spectrum  = NULL;
-		double std = -1.;
-		double std_mad = -1.;
-		cpl_mask *mask_in = NULL;
+        /* Compute Pattern noise */
+        cpl_image *power_spectrum  = NULL;
+        double std = -1.;
+        double std_mad = -1.;
+        cpl_mask *mask_in = NULL;
         //cpl_frameset_dump(fs_masks,stdout);
-		//if (n_frame < n_masks && n_masks > 0) {
-		if (n_masks > 0) {
+        //if (n_frame < n_masks && n_masks > 0)
+        if (n_masks > 0) {
             /* only one input mask is expected for each chip */
-			cpl_frame  *frm_mask = cpl_frameset_get_position(fs_masks, 0);
-			const char *filename_mask = cpl_frame_get_filename(frm_mask);
+            cpl_frame  *frm_mask = cpl_frameset_get_position(fs_masks, 0);
+            const char *filename_mask = cpl_frame_get_filename(frm_mask);
 
-			/* Load input mask, UVES format: extension id is 0: common mask */
-			cpl_msg_info(cpl_func,"Load mask, filename=%s ...", filename_mask);
-			mask_in = cpl_mask_load(filename_mask, 0, 0);
-		}
+            /* Load input mask, UVES format: extension id is 0: common mask */
+            cpl_msg_info(cpl_func,"Load mask, filename=%s ...", filename_mask);
+            mask_in = cpl_mask_load(filename_mask, 0, 0);
+        }
 
-		if (hdrl_fpn_compute(img_in, mask_in, dc_mask_x, dc_mask_y,
-				&power_spectrum, &std, &std_mad) != CPL_ERROR_NONE) {
+        if (hdrl_fpn_compute(img_in, mask_in, dc_mask_x, dc_mask_y,
+                &power_spectrum, &std, &std_mad) != CPL_ERROR_NONE) {
 
-			if (img_in     ) cpl_image_delete(img_in);
-			if (mask_in    ) cpl_mask_delete(mask_in);
-			if (power_spectrum ) cpl_image_delete(power_spectrum);
+            if (img_in     ) cpl_image_delete(img_in);
+            if (mask_in    ) cpl_mask_delete(mask_in);
+            if (power_spectrum ) cpl_image_delete(power_spectrum);
 
-			return cpl_error_get_code();
-		}
+            return cpl_error_get_code();
+        }
 
-		cpl_propertylist *plist = cpl_propertylist_new();
-		cpl_propertylist *xlist = cpl_propertylist_new();
+        cpl_propertylist *plist = cpl_propertylist_new();
+        cpl_propertylist *xlist = cpl_propertylist_new();
 
-		/* Add STD */
-		if (!isnan(std)) {
-			cpl_propertylist_update_double(plist, "ESO QC PD STD", std);
-			cpl_propertylist_update_double(xlist, "ESO QC PD STD", std);
+        /* Add STD */
+        if (!isnan(std)) {
+            cpl_propertylist_update_double(plist, "ESO QC PD STD", std);
+            cpl_propertylist_update_double(xlist, "ESO QC PD STD", std);
 
-		} else {
-			cpl_propertylist_update_double(plist, "ESO QC PD STD", -DBL_MAX);
-			cpl_propertylist_update_double(xlist, "ESO QC PD STD", -DBL_MAX);
-		}
+        } else {
+            cpl_propertylist_update_double(plist, "ESO QC PD STD", -DBL_MAX);
+            cpl_propertylist_update_double(xlist, "ESO QC PD STD", -DBL_MAX);
+        }
 
-		/* Add Peak value */
-		if (!isnan(std_mad)) {
-			cpl_propertylist_update_double(plist, "ESO QC PD STDMAD", std_mad);
-			cpl_propertylist_update_double(xlist, "ESO QC PD STDMAD", std_mad);
-		} else {
-			cpl_propertylist_update_double(plist, "ESO QC PD STDMAD", -DBL_MAX);
-			cpl_propertylist_update_double(xlist, "ESO QC PD STDMAD", -DBL_MAX);
-		}
+        /* Add Peak value */
+        if (!isnan(std_mad)) {
+            cpl_propertylist_update_double(plist, "ESO QC PD STDMAD", std_mad);
+            cpl_propertylist_update_double(xlist, "ESO QC PD STDMAD", std_mad);
+        } else {
+            cpl_propertylist_update_double(plist, "ESO QC PD STDMAD", -DBL_MAX);
+            cpl_propertylist_update_double(xlist, "ESO QC PD STDMAD", -DBL_MAX);
+        }
 
 
         /* Save pattern noise mask image */
         cpl_propertylist_update_string(plist, CPL_DFS_PRO_CATG,
-        		UVES_BIAS_PD_MASK(chip));
+                        UVES_BIAS_PD_MASK(chip));
 
         /* Create an output frameset */
         cpl_frameset *usedframes = cpl_frameset_new();
@@ -379,21 +379,22 @@ uves_mbias_fpn(const cpl_imagelist *raw_images,bool blue, enum uves_chip chip,
 
         cpl_image *out_mask_image = cpl_image_new_from_mask(cpl_image_get_bpm(power_spectrum));
         if(n_frame == 0) {
-        	/* only 1st extension as mask is common  for all input raw data */
-        	cpl_dfs_save_image(frames, NULL, parameters, frames, frm_raw,
-        			out_mask_image, CPL_TYPE_INT, recipe_id, plist, NULL,
-					PACKAGE "/" PACKAGE_VERSION, out_filename_mask);
+            /* only 1st extension as mask is common  for all input raw data */
+            cpl_dfs_save_image(frames, NULL, parameters, frames, frm_raw,
+                out_mask_image, CPL_TYPE_INT, recipe_id, plist, NULL,
+                PACKAGE "/" PACKAGE_VERSION, out_filename_mask);
         }
 
         /* power spectrum */
         cpl_propertylist_update_string(plist, CPL_DFS_PRO_CATG, UVES_BIAS_PD(chip));
 
         if(n_frame == 0) {
-        	cpl_dfs_save_image(frames, NULL, parameters, frames, frm_raw,
-        			power_spectrum, CPL_TYPE_DOUBLE, recipe_id, plist, NULL,
-					PACKAGE "/" PACKAGE_VERSION, out_filename);
+            cpl_dfs_save_image(frames, NULL, parameters, frames, frm_raw,
+                power_spectrum, CPL_TYPE_DOUBLE, recipe_id, plist, NULL,
+                PACKAGE "/" PACKAGE_VERSION, out_filename);
         } else {
-        	cpl_image_save(power_spectrum, out_filename, CPL_TYPE_DOUBLE, xlist, CPL_IO_EXTEND);
+            uves_sanitise_propertylist(xlist);
+            cpl_image_save(power_spectrum, out_filename, CPL_TYPE_DOUBLE, xlist, CPL_IO_EXTEND);
         }
 
         if(out_mask_image) cpl_image_delete(out_mask_image);
@@ -404,12 +405,12 @@ uves_mbias_fpn(const cpl_imagelist *raw_images,bool blue, enum uves_chip chip,
         cpl_propertylist_delete(plist);
         cpl_propertylist_delete(xlist);
 
-	}
-	cpl_frameset_delete(fs_raws);
-	cpl_frameset_delete(fs_masks);
-	cpl_free(out_filename);
-	cpl_free(out_filename_mask);
-	return cpl_error_get_code();
+    }
+    cpl_frameset_delete(fs_raws);
+    cpl_frameset_delete(fs_masks);
+    cpl_free(out_filename);
+    cpl_free(out_filename_mask);
+    return cpl_error_get_code();
 }
 /*----------------------------------------------------------------------------*/
 /**
