@@ -1554,7 +1554,7 @@ uves_orderpos_exe_body(cpl_frameset *frames,
         sprintf(extname,"ORDER_INFO");
         uves_pfits_set_extname(table_header,extname);
 
-        check( cpl_table_save(traces,
+        check( uves_table_save(traces,
                       NULL,            /* Primary header, 
                               ignored when mode is IO_EXTEND */
                       table_header,            /* Extension header               */
