@@ -318,7 +318,7 @@ uves_locate_orders(const cpl_image *inputimage,
             cpl_table_new_column(tracetable, "OrderSlope"     , CPL_TYPE_DOUBLE)),  
       /* The order's RMS (from linear fit) */
       "Could not initialize order trace table");
-    
+
     /* Info about the order */
     check(( cpl_table_new_column(ordertable, "Xcenter",      CPL_TYPE_INT),
         cpl_table_new_column(ordertable, "Ycenter",      CPL_TYPE_INT),
@@ -914,6 +914,17 @@ uves_locate_orders(const cpl_image *inputimage,
         }
     }
 
+    cpl_table_set_column_unit(tracetable,"Order","");
+    cpl_table_set_column_unit(tracetable,"X","pix");
+    cpl_table_set_column_unit(tracetable,"Y","pix");
+    cpl_table_set_column_unit(tracetable,"dY","pix");
+    cpl_table_set_column_unit(tracetable,"Residual_Square","pix*pix");
+
+    cpl_table_set_column_unit(tracetable,"Yfit","pix");
+    cpl_table_set_column_unit(tracetable,"dYfit_Square","pix");
+    cpl_table_set_column_unit(tracetable,"Residual","pix");
+
+
     /* Plot results */
     check( uves_plot_table(tracetable, "X", "Yfit", "%d orders detected", *orders_traced),
        "Plotting failed");
