@@ -245,7 +245,7 @@ uves_rebin_define_parameters(void)
 		char* full_name = uves_sprintf("%s.%s", UVES_REBIN_ID, name);
 		uves_parameter_new_range(p, full_name,
 				CPL_TYPE_DOUBLE,
-				"The bin size used for REDU data (in w.l.u.) in wavelength space. "
+				"The bin size used for BLUE/REDL data (in w.l.u.) in wavelength space. "
 				"If negative, a step size of "
 				"2/3 * ( average pixel size ) is used.",
 				UVES_REBIN_ID,
@@ -272,15 +272,14 @@ uves_rebin_define_parameters(void)
 		full_name = uves_sprintf("%s.%s", UVES_REBIN_ID, name);
 		uves_parameter_new_value(p, full_name,
 				CPL_TYPE_BOOL,
-				"Whether or not to multiply by the factor "
-				"dx/dlambda (pixels per wavelength) "
-				"during the rebinning. This option is disabled "
-				"as default in concordance with the "
-				"method used in the MIDAS pipeline. This "
-				"option should be set to true "
-				"to convert the observed flux (in pixel-space) "
-				"to a flux per wavelength (in "
-				"wavelength-space).",
+                                "Whether or not to multiply by the factor "
+                                "dx/dlambda (pixels per wavelength) "
+                                "during the rebinning to conserve the flux. "
+                                "This option is disabled as default because "
+                                "applying the flat field correction already "
+                                "ensures flux conservation. Therefore this "
+                                "parameter should be TRUE (for response and "
+                                "science data) only if reduce.ffmethd = no.",
 				UVES_REBIN_ID,
 				false);
 		cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, name);
