@@ -229,7 +229,7 @@ uves_normalize_spectrum(const cpl_image *spectrum, const cpl_image *spectrum_err
     int miss_airm_end=0;
     {
         double airmass_start, airmass_end;
-        if(cpl_propertylist_has(raw_header,UVES_AIRMASS_START)) {
+        if(uves_propertylist_has(raw_header,UVES_AIRMASS_START)) {
             check( airmass_start = uves_pfits_get_airmass_start(raw_header),
                             "Error reading airmass start");
         } else {
@@ -241,7 +241,7 @@ uves_normalize_spectrum(const cpl_image *spectrum, const cpl_image *spectrum_err
             uves_msg_warning("Missing %s approximate it", UVES_AIRMASS_START);
 
         }
-        if(cpl_propertylist_has(raw_header,UVES_AIRMASS_END)) {
+        if(uves_propertylist_has(raw_header,UVES_AIRMASS_END)) {
             check( airmass_end = uves_pfits_get_airmass_end(raw_header),
                             "Error reading airmass end");
         } else {
