@@ -16,7 +16,7 @@
  *   along with this program; if not, write to the Free Software                *
  *   Foundation, 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA       *
  *                                                                              */
- 
+
 /*
  * $Author: amodigli $
  * $Date: 2013-08-08 13:36:46 $
@@ -71,19 +71,19 @@
 
 static cpl_boolean
 uves_is_new_flux_std(uves_propertylist* plist){
-	cpl_boolean result=CPL_FALSE;
-	const char* targ_name = uves_pfits_get_targ_name(plist);
-	if(  strcmp(targ_name,"GD71") == 0 ||
-			strcmp(targ_name,"GD153") == 0 ||
-			strcmp(targ_name,"LTT3218") == 0 ||
-			strcmp(targ_name,"LTT7987") == 0 ||
-			strcmp(targ_name,"Feige110") == 0 ||
-			strcmp(targ_name,"EG21") == 0 ||
-			strcmp(targ_name,"EG274") == 0 )
-	{
-		result=CPL_TRUE;
-	}
-	return result;
+    cpl_boolean result=CPL_FALSE;
+    const char* targ_name = uves_pfits_get_targ_name(plist);
+    if(  strcmp(targ_name,"GD71") == 0 ||
+            strcmp(targ_name,"GD153") == 0 ||
+            strcmp(targ_name,"LTT3218") == 0 ||
+            strcmp(targ_name,"LTT7987") == 0 ||
+            strcmp(targ_name,"Feige110") == 0 ||
+            strcmp(targ_name,"EG21") == 0 ||
+            strcmp(targ_name,"EG274") == 0 )
+    {
+        result=CPL_TRUE;
+    }
+    return result;
 }
 /**@{*/
 /**
@@ -103,7 +103,7 @@ uves_is_new_flux_std(uves_propertylist* plist){
   @param    flux_table          Catalogue standard star fluxes
   @param    atm_extinction      Atmospheric extinction coefficients
   @param    chip                CCD chip
-  @param    debug_mode               If set to true, intermediate results are saved to 
+  @param    debug_mode               If set to true, intermediate results are saved to
                                 the current directory
   @param    parameters          The recipe parameter list containing parameters
                                 for background subtraction, flat-fielding, extraction, rebinning
@@ -111,21 +111,21 @@ uves_is_new_flux_std(uves_propertylist* plist){
   @param    efficiency          (out) The quantum detection efficiency table
   @param    blaze_efficiency    (out) Efficiency at blaze function maximum, for each order
   @return   The reduced spectrum
-  
+
 **/
 /*----------------------------------------------------------------------------*/
 cpl_error_code
-uves_response_efficiency(const cpl_image *raw_image, 
-                         const uves_propertylist *raw_header, 
+uves_response_efficiency(const cpl_image *raw_image,
+                         const uves_propertylist *raw_header,
                          const uves_propertylist *rotated_header,
                          const cpl_image *master_bias,
                          const uves_propertylist *mbias_header,
-                         const cpl_image *master_dark, 
-                         const uves_propertylist *mdark_header, 
-                         const cpl_table *ordertable, 
+                         const cpl_image *master_dark,
+                         const uves_propertylist *mdark_header,
+                         const cpl_table *ordertable,
                          const polynomial *order_locations,
-                         const cpl_table *linetable[3], 
-                         const uves_propertylist *linetable_header[3], 
+                         const cpl_table *linetable[3],
+                         const uves_propertylist *linetable_header[3],
                          const polynomial *dispersion_relation[3],
                          const cpl_table *flux_table,
                          const cpl_table *atm_extinction,
@@ -162,9 +162,8 @@ uves_response_efficiency(const cpl_image *raw_image,
                            calculated in the first extraction */
 
     char *ref_obj_id = NULL;
-    
+
     double wavestep;
-    double extraction_slit;
     cpl_image* wave_map=NULL;
     cpl_image* reduced_rebinned_no_bpm=NULL;
     cpl_mask* bpm=NULL;
@@ -176,20 +175,20 @@ uves_response_efficiency(const cpl_image *raw_image,
     */
     {
     double smooth_step;
-    
+
     /* wavestep */
-    check( uves_get_parameter(parameters, NULL, 
-                  make_str(UVES_RESPONSE_ID) "", "reduce.rebin.wavestep", 
+    check( uves_get_parameter(parameters, NULL,
+                  make_str(UVES_RESPONSE_ID) "", "reduce.rebin.wavestep",
                   CPL_TYPE_DOUBLE, &wavestep),
            "Error getting resampling step size");
-    
+
     check( smooth_step = cpl_table_get_column_mean(linetable[1], LINETAB_PIXELSIZE),
            "Error reading mean pixelsize");
-    
+
     smooth_step = 10*2*smooth_step/3;
-        
+
     /* Cast to non-const is okay. The parameter is reset to its previous value
-       (see below), so there is not net change (unless the reduction fails, 
+       (see below), so there is not net change (unless the reduction fails,
        in which case parameter list will change).
     */
     check( uves_set_parameter((cpl_parameterlist *) parameters,
@@ -197,99 +196,98 @@ uves_response_efficiency(const cpl_image *raw_image,
                   CPL_TYPE_DOUBLE, &smooth_step),
            "Error setting resampling step size");
     }
-    
-    check( uves_reduce(raw_image, 
-                       raw_header, 
+
+    check( uves_reduce(raw_image,
+                       raw_header,
                        rotated_header,
-               master_bias,
-                      mbias_header,
-               master_dark, 
+                       master_bias,
+                       mbias_header,
+                       master_dark,
                        mdark_header,
-               NULL, 
-                       NULL,                              /* No master flat */
-               ordertable, 
+                       NULL,
+                       NULL,  /* No master flat */
+                       ordertable,
                        order_locations,
-               linetable, 
-                       linetable_header, 
+                       linetable,
+                       linetable_header,
                        dispersion_relation,
-               chip,
-               debug_mode, 
-               parameters, 
+                       chip,
+                       debug_mode,
+                       parameters,
                        make_str(UVES_RESPONSE_ID),
                        ".efficiency",
-               /* Output */
-               NULL, 
-                       NULL, 
-                       NULL,                        /* 2d products */
-               NULL,                        /* Cosmic ray table */
-               &wave_map,
-               &background,
-               NULL, 
-                       NULL,                        /* Variance of flat-fielded spectrum */
-               NULL, 
-                       NULL,                        /* Don't need these 
-                               intermediate products */
-               &merged_sky,
-               &rebinned_spectrum, 
-                       &rebinned_noise, 
+                       /* Output */
+                       NULL,
+                       NULL,
+                       NULL,  /* 2d products */
+                       NULL,  /* Cosmic ray table */
+                       &wave_map,
+                       &background,
+                       NULL,
+                       NULL,  /* Variance of flat-fielded spectrum */
+                       NULL,
+                       NULL,  /* Don't need these intermediate products */
+                       &merged_sky,
+                       &rebinned_spectrum,
+                       &rebinned_noise,
                        &rebinned_header,
-               &merged_spectrum, 
-                       &merged_noise, 
+                       &merged_spectrum,
+                       &merged_noise,
                        &reduced_header,
-               &reduced_rebinned, 
+                       &reduced_rebinned,
                        &reduced_rebinned_noise,
-               &reduced_spectrum, 
+                       &reduced_spectrum,
                        &reduced_noise,
                        &info_tbl,
-               &extraction_slit,   /* not passed on to the caller */
+                       &(double){0},  /* discard extraction_slit product */
                        NULL),
        "Could not reduce frame");
-    
+
     /* Reset parameter to previous value */
     {
     uves_msg_debug("Resetting parameter wavestep = %e", wavestep);
 
     /* Cast to non-const is okay. There is no net change in the parameter list (see above). */
-    check( uves_set_parameter((cpl_parameterlist *) parameters, 
-                  make_str(UVES_RESPONSE_ID) "", "reduce.rebin.wavestep", 
+    check( uves_set_parameter((cpl_parameterlist *) parameters,
+                  make_str(UVES_RESPONSE_ID) "", "reduce.rebin.wavestep",
                   CPL_TYPE_DOUBLE, &wavestep),
            "Error resetting resampling step size");
     }
-    
-    
+
+
     /* Save reduced spectrum */
-    if (debug_mode) 
+    if (debug_mode)
     {
         /* Window number doesn't apply. This is middle window minus two other (sky) windows */
-        check( uves_save_image_local("Reduced spectrum (2d)", "reduced", 
-                     reduced_rebinned, chip, -1, -1, rebinned_header, true), 
+        check( uves_save_image_local("Reduced spectrum (2d)", "reduced",
+                     reduced_rebinned, chip, -1, -1, rebinned_header, true),
            "Error saving reduced spectrum (2d)");
-        
-        check( uves_save_image_local("Reduced spectrum (2d) noise", "errreduced", 
+
+        check( uves_save_image_local("Reduced spectrum (2d) noise", "errreduced",
                      reduced_rebinned_noise, chip, -1, -1, rebinned_header, true),
            "Error saving reduced spectrum (2d) noise");
 
-        check( uves_save_image_local("Reduced spectrum", "merged", 
-                     reduced_spectrum, chip, -1, -1, reduced_header, true), 
+        check( uves_save_image_local("Reduced spectrum", "merged",
+                     reduced_spectrum, chip, -1, -1, reduced_header, true),
            "Error saving reduced spectrum");
-        
-        check( uves_save_image_local("Reduced spectrum noise", "errmerged", 
-                     reduced_noise, chip, -1, -1, reduced_header, true), 
+
+        check( uves_save_image_local("Reduced spectrum noise", "errmerged",
+                     reduced_noise, chip, -1, -1, reduced_header, true),
            "Error saving reduced spectrum noise");
     }
-    
+
     uves_msg("Dividing by catalogue flux");
     /*
-     * Calculate 2d response curve  (don't scale to unit exposure time, binning, gain, ... ) 
+     * Calculate 2d response curve  (don't scale to unit exposure time, binning, gain, ... )
      */
-    /* in some cases are flagged too many bad pixels on sky frames used 
-       to compute reduced object in linear extraction method, this 
+    /* in some cases are flagged too many bad pixels on sky frames used
+       to compute reduced object in linear extraction method, this
        affecting the number of bad pixels of the reduced_rebinned obj spectrum
        to fix this we erase the associated bad pixel map
     */
     reduced_rebinned_no_bpm=cpl_image_duplicate(reduced_rebinned);
     bpm=cpl_image_unset_bpm(reduced_rebinned_no_bpm);
-    check( response_orders = uves_calculate_response(reduced_rebinned_no_bpm, 
+    check( response_orders = uves_calculate_response(reduced_rebinned_no_bpm,
                                                      rebinned_header,
                                                      flux_table,
                                                      raw_header, PACCURACY,
@@ -312,10 +310,10 @@ uves_response_efficiency(const cpl_image *raw_image,
      */
     {
     int n_traces = cpl_image_get_size_y(merged_spectrum);    /* Number of spatial traces */
-    
+
     assure( n_traces == 1, CPL_ERROR_ILLEGAL_INPUT,
         "2d extraction/reduction not supported");
-    
+
     check( efficiency_spectrum = uves_normalize_spectrum(response_orders, NULL,
                                  /* Spectrum, noise */
                                  rebinned_header,
@@ -335,7 +333,7 @@ uves_response_efficiency(const cpl_image *raw_image,
     check( uves_filter_image_median(&efficiency_spectrum, 3, 0, false),
        "Error applying median filter");
 
-    
+
     uves_msg("Calculating quantum detection efficiency");
 
     {
@@ -354,7 +352,7 @@ uves_response_efficiency(const cpl_image *raw_image,
     nx      = cpl_image_get_size_x(raw_image);
     nbins   = cpl_image_get_size_x(efficiency_spectrum);
     norders = cpl_image_get_size_y(efficiency_spectrum);
-    
+
     *efficiency = cpl_table_new(nbins * norders);
     cpl_table_new_column(*efficiency, "Wave", CPL_TYPE_DOUBLE);
     cpl_table_new_column(*efficiency, "Eff", CPL_TYPE_DOUBLE);
@@ -366,15 +364,15 @@ uves_response_efficiency(const cpl_image *raw_image,
     cpl_table_set_column_unit(*efficiency,"Order"," ");
     cpl_boolean is_new_flux_std = uves_is_new_flux_std(raw_header);
     row = 0;
-    
-    check( first_abs_order = uves_pfits_get_firstabsorder(linetable_header[1]), 
+
+    check( first_abs_order = uves_pfits_get_firstabsorder(linetable_header[1]),
            "Could not read order numbers from line table header");
-    check( last_abs_order  = uves_pfits_get_lastabsorder (linetable_header[1]), 
+    check( last_abs_order  = uves_pfits_get_lastabsorder (linetable_header[1]),
            "Could not read order numbers from line table header");
-    
+
     check( dlambda = uves_pfits_get_cdelt1(rebinned_header),
            "Error reading bin width from header");
-    
+
     check( average_noise = cpl_image_get_median(reduced_rebinned_noise),
            "Error reading median noise level");
 
@@ -388,12 +386,12 @@ uves_response_efficiency(const cpl_image *raw_image,
 
         check( lambda_start = uves_pfits_get_wstart(rebinned_header, order),
                "Error reading start wavelength from header");
-        
+
         check( lambda_end   = uves_pfits_get_wend(rebinned_header, order),
                "Error reading end wavelength from header");
 
         /* Get 1d dispersion relation for this order
-           f_1d = f(x, m=abs_order) 
+           f_1d = f(x, m=abs_order)
 
            Collapsing a polynomial is slow, so do it
            only once per order
@@ -406,17 +404,17 @@ uves_response_efficiency(const cpl_image *raw_image,
 
         x = 1;
         for (lambda = lambda_start, bin = 1;
-             lambda < lambda_end + 0.5 * dlambda && bin <= nbins; 
+             lambda < lambda_end + 0.5 * dlambda && bin <= nbins;
              bin++, lambda += dlambda)
             {
             double flux;
             double dldx;
-            double noise;            /* Only use positions with low noise 
+            double noise;            /* Only use positions with low noise
                             (middle of blaze function) */
-            
-            /* flux  = cpl_image_get(efficiency_spectrum, 
+
+            /* flux  = cpl_image_get(efficiency_spectrum,
                                      bin, order, &pis_rejected);
-               noise = cpl_image_get(reduced_rebinned_noise, 
+               noise = cpl_image_get(reduced_rebinned_noise,
                bin, order, &pis_rejected); */
             flux  = efficiency_data   [(bin-1) + (order-1) * nbins];
             noise = reduced_noise_data[(bin-1) + (order-1) * nbins];
@@ -424,7 +422,7 @@ uves_response_efficiency(const cpl_image *raw_image,
 
             /*
              *   Energy per (time * area * wavelength) =
-             *    ((electron counts)/gain) * (hc/lambda) / 
+             *    ((electron counts)/gain) * (hc/lambda) /
              *    (time * area * |dlambda/dx|)
              *
              *   We already divided by exposure time, gain
@@ -436,29 +434,29 @@ uves_response_efficiency(const cpl_image *raw_image,
              *
              * This is equivalent to solving f_1d(x) = m*lambda
             */
-            
+
             check( x = uves_polynomial_solve_1d(
-                   disprel_1d, 
+                   disprel_1d,
                    abs_order * lambda, /* right hand side    */
                    x,                  /* guess              */
                    1),                 /* multiplicity       */
                    "Could not solve dispersion relation for x "
                    "at (m, lambda) = (%d, %f)", abs_order, lambda);
-            
+
 
 
             /*  For constant absolute order number, m:
                 dl/dx  =  d (l.m)/dx / m  */
-            
+
             check( dldx = fabs(uves_polynomial_derivative_2d(
-                           dispersion_relation[1], 
-                           x, 
+                           dispersion_relation[1],
+                           x,
                            abs_order, 1) / abs_order),
                    "Could not evaluate dispersion relation");
-            
+
                         /* Don't make a linear interpolation
             weight = (lambda - lambda_start) / (lambda_end - lambda_start);
-            
+
             check( dldx =
                    fabs(uves_polynomial_derivative_2d(
                     dispersion_relation[1],
@@ -478,8 +476,8 @@ uves_response_efficiency(const cpl_image *raw_image,
             */
 
 
-            	flux = flux  * 1e17 * H_BAR * SPEED_OF_LIGHT /
-            	                (dldx * lambda * TELESCOPE_EFFECTIVE_AREA);
+            flux = flux  * 1e17 * H_BAR * SPEED_OF_LIGHT /
+                            (dldx * lambda * TELESCOPE_EFFECTIVE_AREA);
 
 
             /* The factor 1e17 accounts for the conversion Joule<-erg
@@ -501,9 +499,9 @@ uves_response_efficiency(const cpl_image *raw_image,
                 }
             }
         }
-    
+
     /* Remove unused rows of efficiency table */
-    check( cpl_table_set_size(*efficiency, row), 
+    check( cpl_table_set_size(*efficiency, row),
            "Error setting size of efficiency table to %d rows", row);
     /* remove negative efficiency points */
     cpl_table* tmp=cpl_table_duplicate(*efficiency);
@@ -520,7 +518,7 @@ uves_response_efficiency(const cpl_image *raw_image,
     cpl_table_new_column(*blaze_efficiency, "Wave" , CPL_TYPE_DOUBLE);
     cpl_table_new_column(*blaze_efficiency, "Eff"  , CPL_TYPE_DOUBLE);
     row = 0;
-    
+
     for (order = 1; order <= norders; order++)
         {
         double lambda_min;
@@ -538,21 +536,21 @@ uves_response_efficiency(const cpl_image *raw_image,
 
         check( lambda_max = uves_pfits_get_wend(rebinned_header, order),
                "Error reading bin width from header");
-        
+
         lambda_central_min = lambda_min + 0.4 * (lambda_max - lambda_min);
         lambda_central     = lambda_min + 0.5 * (lambda_max - lambda_min);
         lambda_central_max = lambda_min + 0.6 * (lambda_max - lambda_min);
-        
-        /* Select rows in this order in range 
+
+        /* Select rows in this order in range
            ]lambda_central_min ; lambda_central_max[ */
         cpl_table_select_all(*efficiency);
-        cpl_table_and_selected_int   (*efficiency, "Order", 
+        cpl_table_and_selected_int   (*efficiency, "Order",
                           CPL_EQUAL_TO    , order);
-        cpl_table_and_selected_double(*efficiency, "Wave" , 
+        cpl_table_and_selected_double(*efficiency, "Wave" ,
                           CPL_GREATER_THAN, lambda_central_min);
-        cpl_table_and_selected_double(*efficiency, "Wave" , 
+        cpl_table_and_selected_double(*efficiency, "Wave" ,
                           CPL_LESS_THAN   , lambda_central_max);
-        
+
         uves_msg_debug("%" CPL_SIZE_FORMAT " bins in central 20 %% range of order #%d",
                    cpl_table_count_selected(*efficiency), order);
 
@@ -563,9 +561,9 @@ uves_response_efficiency(const cpl_image *raw_image,
 
             /* Get 90% percentile efficiency */
             uves_sort_table_1(central_efficiency, "Eff", false);     /* Ascending */
-            
+
             top_efficiency = cpl_table_get_double(
-                central_efficiency, "Eff", 
+                central_efficiency, "Eff",
                 (int) (0.9 * cpl_table_get_nrow(central_efficiency)), NULL);
             }
         else
@@ -574,8 +572,8 @@ uves_response_efficiency(const cpl_image *raw_image,
                        order);
             top_efficiency = 0;
             }
-        
-        uves_msg("Efficiency(lambda = %.2f A) = %.2f%%", 
+
+        uves_msg("Efficiency(lambda = %.2f A) = %.2f%%",
              lambda_central, top_efficiency*100);
 
         check(( cpl_table_set_int   (*blaze_efficiency, "Order", row, order),
@@ -605,7 +603,7 @@ uves_response_efficiency(const cpl_image *raw_image,
     uves_free_image(&efficiency_spectrum);
     uves_free_table(&central_efficiency);
     uves_free_table(&info_tbl);
-    
+
     cpl_free(ref_obj_id);
 
     if (cpl_error_get_code() != CPL_ERROR_NONE)
@@ -613,7 +611,7 @@ uves_response_efficiency(const cpl_image *raw_image,
         uves_free_table(efficiency);
         uves_free_table(blaze_efficiency);
     }
-    
+
     return cpl_error_get_code();
 }
 /**@}*/
